@@ -2,7 +2,7 @@ CTM_registry <- list(CTM_VEM.fit = c("VEM", "CTM_VEM", "CTM_VEM.fit"))
 
 CTM <- function(x, k, method = "VEM", control = NULL, model = NULL, ...) {
   if (is(x, "DocumentTermMatrix")) {
-    if (!any(attr(x, "Weighting") %in% c("term frequency", "tf"))) {
+    if (!any(attr(x, "weighting") %in% c("term frequency", "tf"))) {
       stop("The DocumentTermMatrix needs to have a term frequency weighting")
     }
   } else if (!is(x, "simple_triplet_matrix")) {
